fn create_heartbeat_message() -> ControllinoMessageExpand description
Creates a heartbeat message to be sent to the Controllino.
This function constructs a standard ControllinoMessage with the heartbeat
command character. This is used to periodically signal to the hardware
that the control software is still active.
Returns
A new ControllinoMessage configured for a heartbeat.